@@ -22,10 +22,20 @@ from subprocess import call, PIPE
 from optparse import OptionParser, Option
 from ConfigParser import RawConfigParser
 
+#TODO: Replace all instances of cal/PIPE with getoutput
+from commands import getoutput
+
+# get information about the currently logged in user
+user = environ["HOME"].split("/")[-1]
+uid = getoutput("id -u %s" % user)
+gid = getoutput("id -g %s" % user)
+
 # create config directory if it doesn't already exist
 config_dir = environ["HOME"] + "/.config/aptly/"
+
 try:
     makedirs(config_dir)
+    getoutput("chown  %s:%s %s" %(uid, gid, config_dir))
 except OSError:
     pass
 
@@ -39,6 +49,7 @@ except IOError:
     # create a default settings file if one can't be found
     config.add_section("General")
     config.write(open(settings_file, "wb"))
+    getoutput("chown %s:%s %s" %(uid, gid, settings_file))
 
 def install_callback(option, opt_str, value, parser):
     """ Handles installing of remote and local packages using apt-get and
@@ -145,6 +156,7 @@ def cache_callback(option, opt_str, value, parser):
 
         config.set("General", "cache", custom_cache_dir)
         config.write(open(settings_file, "wb"))
+        getoutput("chown %s:%s %s" %(uid, gid, settings_file))
 
         partial_dir = custom_cache_dir + "partial"
         try:
